@@ -207,8 +207,27 @@ def display_boundingBox(boxes_merged, canvas):
 
     return canvas
 
+def create_canvas():
+    from PIL import Image, ImageDraw, ImageFont
+    mode= 'RGB' # for colorimage"L" (luminance)forgreyscaleimages,"RGB"for truecolorimages,and "CMYK"forpre-pressimages.
+    image= None 
+    #set image size to A4
+    width= 2480
+    height= 3508
+    size= (width,height) #w,h@300ppi    I
+    color= (255,255,255) 
+    # specified font size 
+    font= ImageFont.truetype("/Library/Fonts/Arial Unicode.ttf", 24)
+    
+    
+    #for page in range(0,len(document.pages)): 
+    image= Image.new(mode, size, color)
+    draw= ImageDraw.Draw(image)
+    
+    return {'image':image, 'draw':draw, 'width':width, 'height':height, 'font':font}
+ 
         
-def get_lines_in_boundingBox(document, paragraph_box):
+def get_lines_in_boundingBox(page, paragraph_box):
     #logging.info('finding features... ')
 
     # Coordinates are from top-left corner [0,0] to bottom-right [1,1]
@@ -275,7 +294,7 @@ def group_boundingBox_by_proximity(rec, dist_x=20, dist_y=0):
     
     return np.asarray(final)
 
-def extract_paragraphs(page, dist_x=0, dist_y = 0.007, display=False):
+def extract_paragraphs(filen, page, dist_x=0, dist_y = 0.007, display=False):
 
     canvas = None
     all_parapraphs = []
@@ -310,31 +329,14 @@ def extract_paragraphs(page, dist_x=0, dist_y = 0.007, display=False):
             
     return all_parapraphs
 
-def create_canvas():
-    from PIL import Image, ImageDraw, ImageFont
-    mode= 'RGB' # for colorimage"L" (luminance)forgreyscaleimages,"RGB"for truecolorimages,and "CMYK"forpre-pressimages.
-    image= None 
-    #set image size to A4
-    width= 2480
-    height= 3508
-    size= (width,height) #w,h@300ppi    I
-    color= (255,255,255) 
-    # specified font size 
-    font= ImageFont.truetype("/Library/Fonts/Arial Unicode.ttf", 24)
-    
-    
-    #for page in range(0,len(document.pages)): 
-    image= Image.new(mode, size, color)
-    draw= ImageDraw.Draw(image)
-    
-    return {'image':image, 'draw':draw, 'width':width, 'height':height, 'font':font}
-    
+   
                 
 if __name__ == "__main__":
     
     filen = '.json'
     
     
+    
     import trp
     
     with open(filen,'rt') as handle:
@@ -345,9 +347,10 @@ if __name__ == "__main__":
             document = trp.Document(doc)
             
     
-
-    page = document.pages[1]
-    all_paragraphs = extract_paragraphs(page, dist_x=0, dist_y = 0.007, display=True)
+    all_paragraphs = []
+    for i,page in enumerate(document.pages):
+        #page = document.pages[1]
+        all_paragraphs.extend(extract_paragraphs(filen, page, dist_x=0, dist_y = 0.007, display=False))
 
 
 
